- [x] remove support of pydantic v1, dataclass 
- [x] add DefineSubset class
- [x] optimize the analysis process by cache
- [x] experimental: add er diagram/model tool
- [ ] optimize the analysis result to better display in voyager